@@ -185,9 +185,14 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         '''
         return True
 
-    def performLogin(self):
+    def performLogin(self,data):
         params = {}
 
+        if data and "Log Out" in data:
+            ## already logged in.
+            logger.debug("Already Logged In")
+            return
+
         if self.password:
             params['login'] = self.username
             params['password'] = self.password
@@ -211,6 +216,7 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         d = self._fetchUrl(loginUrl, params)
 
         if "Log Out" not in d:
+            logger.debug(d)
             logger.info("Failed to login to URL %s as %s" % (self.url,
                                                              params['login']))
             raise exceptions.FailedToLogin(self.url,params['login'])
@@ -232,6 +238,9 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         for noscript in soup.find_all('noscript'):
             noscript.extract()
 
+        for iframe in soup.find_all('iframe'):
+            iframe.extract() # calibre book reader & editor don't like iframes to youtube.
+
         for qdiv in self.get_quote_expand_tag(soup):
             qdiv.extract() # Remove <div class="...">click to expand</div>
 
@@ -378,9 +387,35 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
                 tmcat_index += 1
         return threadmarks
 
+
+    def get_last_page_url(self,topsoup):
+        span = topsoup.find('span',{'class':'pageNavHeader'})
+        # logger.debug(span)
+        # span class="pageNavHeader" - not present if no pages
+        # first <nav>?
+        # last not class=text?
+        nav = span.find_next('nav')
+        # logger.debug(nav)
+        lastpage = nav.find_all('a',href=re.compile(r'page-'))[-2]
+        # logger.debug(lastpage)
+        return lastpage['href']
+
+    ## Aug 2019 - SB doesn't send update emails for threads it doesn't
+    ## think you've seen all of since the last email anymore.  Fetch
+    ## the last page of the thread to reset it.  This requires login
+    ## to already have been done.
+    def fetch_last_page(self,topsoup):
+        logger.debug("Perform fetch_last_page")
+        try:
+            # doing make_soup will also cache posts from that last page.
+            self.make_soup(self._fetchUrl(self.getURLPrefix()+'/'+self.get_last_page_url(topsoup)))
+        except:
+            logger.info("fetch_last_page failed, continuing")
+
     ## Getting the chapter list and the meta data, plus 'is adult' checking.
     def extractChapterUrlsAndMetadata(self):
 
+        data = topsoup = souptag = None
         useurl = self.url
         logger.info("url: "+useurl)
 
@@ -388,10 +423,16 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
             (data,opened) = self._fetchUrlOpened(useurl)
             useurl = opened.geturl()
             logger.info("use useurl: "+useurl)
+            # can't login before initial fetch--need a cookie.
+            if self.getConfig('always_login',False) or self.getConfig('fetch_last_page',False):
+                self.performLogin(data)
+                (data,opened) = self._fetchUrlOpened(useurl)
+                useurl = opened.geturl()
+                logger.info("use useurl: "+useurl)
         except HTTPError as e:
             # QQ gives 403, SV at least gives 404.  Which unfortunately
             if e.code == 403 or self.getConfig('always_login',False):
-                self.performLogin()
+                self.performLogin(data)
                 (data,opened) = self._fetchUrlOpened(useurl)
                 useurl = opened.geturl()
                 logger.info("use useurl: "+useurl)
@@ -399,12 +440,17 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
                 raise exceptions.StoryDoesNotExist(self.url)
             else:
                 raise
-        if '#' not in useurl and '/posts/' not in useurl:
-            self._setURL(useurl) ## for when threadmarked thread name changes.
 
         # use BeautifulSoup HTML parser to make everything easier to find.
         topsoup = souptag = self.make_soup(data)
 
+        if '#' not in useurl and '/posts/' not in useurl:
+            self._setURL(useurl) ## for when threadmarked thread name changes.
+
+            # only apply fetch_last_page when not a post url.
+            if self.getConfig('fetch_last_page',False):
+                self.fetch_last_page(topsoup)
+
         self.parse_title(topsoup)
 
         first_post_title = self.getConfig('first_post_title','First Post')
@@ -466,6 +512,9 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
                     self.story.setMetadata('numWords',words)
             souptag = self.get_first_post(topsoup)
 
+        if use_threadmark_chaps:
+            self.set_threadmarks_metadata(useurl,topsoup)
+
         if use_threadmark_chaps or self.getConfig('always_use_forumtags'):
             ## only use tags if threadmarks for chapters or always_use_forumtags is on.
             for tag in self.get_forumtags(topsoup):
@@ -493,13 +542,8 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         # using threadmarks.
         index_post = self.get_post_body(souptag)
 
-        for iframe in index_post.find_all('iframe'):
-            iframe.extract() # calibre book reader & editor don't like iframes to youtube.
-
-        for qdiv in index_post.find_all('div',{'class':'quoteExpand'}):
-            qdiv.extract() # Remove <div class="quoteExpand">click to expand</div>
-
-        self.setDescription(useurl,index_post)
+        if not self.story.getMetadata('description'):
+            self.setDescription(useurl,index_post)
 
         # otherwise, use first post links--include first post since
         # that's often also the first chapter.
@@ -539,6 +583,10 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
             tag.extract()
         self.story.setMetadata('title',stripHTML(h1))
 
+    def set_threadmarks_metadata(self,useurl,topsoup):
+        # None in XF1.
+        return
+
     def get_forumtags(self,topsoup):
         return topsoup.findAll('a',{'class':'tag'}) + topsoup.findAll('span',{'class':'prefix'})
 
@@ -671,9 +719,6 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
 
         postbody = self.get_post_body(souptag)
 
-        for iframe in postbody.find_all('iframe'):
-            iframe.extract() # calibre book reader & editor don't like iframes to youtube.
-
         # XenForo uses <base href="https://forums.spacebattles.com/" />
         return self.utf8FromSoup(self.getURLPrefix()+'/',postbody)
 
