@@ -39,7 +39,7 @@ else: # > 3.0
     def pickle_load(f):
         return pickle.load(f,encoding="bytes")
 
-version="3.10.5"
+version="3.11.0"
 os.environ['CURRENT_VERSION_ID']=version
 
 global_cache = 'global_cache'
@@ -457,7 +457,9 @@ def do_download(arg,
                     metadata = adapter.story.getAllMetadata()
                 call(string.Template(adapter.getConfig('pre_process_cmd')).substitute(metadata), shell=True)
 
-                write_story(configuration, adapter, 'epub')
+                output_filename = write_story(configuration, adapter, 'epub')
+                logger.debug("Successfully wrote '%s'"%output_filename)
+
 
         else:
             if not options.metaonly and adapter.getConfig('pre_process_cmd'):
@@ -468,6 +470,7 @@ def do_download(arg,
                 call(string.Template(adapter.getConfig('pre_process_cmd')).substitute(metadata), shell=True)
 
             output_filename = write_story(configuration, adapter, options.format, options.metaonly)
+            logger.debug("Successfully wrote '%s'"%output_filename)
 
             if options.metaonly and not options.jsonmeta:
                 metadata = adapter.getStoryMetadataOnly().getAllMetadata()
